==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1PriorityClassListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1PriorityClassListFluent<A extends V1beta1PriorityClassListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,V1beta1PriorityClass item);
    public A setToItems(int index,V1beta1PriorityClass item);
    public A addToItems(V1beta1PriorityClass... items);
    public A addAllToItems(Collection<V1beta1PriorityClass> items);
    public A removeFromItems(V1beta1PriorityClass... items);
    public A removeAllFromItems(Collection<V1beta1PriorityClass> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1PriorityClass> getItems();
    public List<V1beta1PriorityClass> buildItems();
    public V1beta1PriorityClass buildItem(int index);
    public V1beta1PriorityClass buildFirstItem();
    public V1beta1PriorityClass buildLastItem();
    public V1beta1PriorityClass buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1PriorityClassBuilder> predicate);
    public A withItems(List<V1beta1PriorityClass> items);
    public A withItems(V1beta1PriorityClass... items);
    public Boolean hasItems();
    public V1beta1PriorityClassListFluent.ItemsNested<A> addNewItem();
    public V1beta1PriorityClassListFluent.ItemsNested<A> addNewItemLike(V1beta1PriorityClass item);
    public V1beta1PriorityClassListFluent.ItemsNested<A> setNewItemLike(int index,V1beta1PriorityClass item);
    public V1beta1PriorityClassListFluent.ItemsNested<A> editItem(int index);
    public V1beta1PriorityClassListFluent.ItemsNested<A> editFirstItem();
    public V1beta1PriorityClassListFluent.ItemsNested<A> editLastItem();
    public V1beta1PriorityClassListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1PriorityClassBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1beta1PriorityClassListFluent.MetadataNested<A> withNewMetadata();
    public V1beta1PriorityClassListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1beta1PriorityClassListFluent.MetadataNested<A> editMetadata();
    public V1beta1PriorityClassListFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1PriorityClassListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1PriorityClassFluent<V1beta1PriorityClassListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1beta1PriorityClassListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1PriorityClassListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1PriorityClassListFluent<A extends V1beta1PriorityClassListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,V1beta1PriorityClass item);
    public A setToItems(int index,V1beta1PriorityClass item);
    public A addToItems(V1beta1PriorityClass... items);
    public A addAllToItems(Collection<V1beta1PriorityClass> items);
    public A removeFromItems(V1beta1PriorityClass... items);
    public A removeAllFromItems(Collection<V1beta1PriorityClass> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1PriorityClass> getItems();
    public List<V1beta1PriorityClass> buildItems();
    public V1beta1PriorityClass buildItem(int index);
    public V1beta1PriorityClass buildFirstItem();
    public V1beta1PriorityClass buildLastItem();
    public V1beta1PriorityClass buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1PriorityClassBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1PriorityClassBuilder> predicate);
    public A withItems(List<V1beta1PriorityClass> items);
    public A withItems(V1beta1PriorityClass... items);
    public Boolean hasItems();
    public V1beta1PriorityClassListFluent.ItemsNested<A> addNewItem();
    public V1beta1PriorityClassListFluent.ItemsNested<A> addNewItemLike(V1beta1PriorityClass item);
    public V1beta1PriorityClassListFluent.ItemsNested<A> setNewItemLike(int index,V1beta1PriorityClass item);
    public V1beta1PriorityClassListFluent.ItemsNested<A> editItem(int index);
    public V1beta1PriorityClassListFluent.ItemsNested<A> editFirstItem();
    public V1beta1PriorityClassListFluent.ItemsNested<A> editLastItem();
    public V1beta1PriorityClassListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1PriorityClassBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1beta1PriorityClassListFluent.MetadataNested<A> withNewMetadata();
    public V1beta1PriorityClassListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1beta1PriorityClassListFluent.MetadataNested<A> editMetadata();
    public V1beta1PriorityClassListFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1PriorityClassListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1PriorityClassFluent<V1beta1PriorityClassListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1beta1PriorityClassListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
